@@ -283,6 +283,7 @@ class Namespace(Doc[T], metaclass=ABCMeta):
                 inspect.isclass(obj)
                 and obj is not empty
                 and not isinstance(obj, GenericAlias)
+                and obj.__qualname__.rpartition(".")[2] == qualname.rpartition(".")[2]
             ):
                 # `dict[str,str]` is a GenericAlias instance. We want to render type aliases as variables though.
                 doc = Class(self.modulename, qualname, obj, taken_from)
@@ -585,7 +586,7 @@ class Class(Namespace[type]):
     @cached_property
     def _var_docstrings(self) -> dict[str, str]:
         docstrings: dict[str, str] = {}
-        for cls in self.obj.__mro__:
+        for cls in self._mro:
             for name, docstr in doc_ast.walk_tree(cls).docstrings.items():
                 docstrings.setdefault(name, docstr)
         return docstrings
@@ -598,7 +599,7 @@ class Class(Namespace[type]):
         annotations: dict[
             str, tuple[Any, type]
         ] = {}  # attribute -> (annotation_unresolved, annotation_resolved)
-        for cls in reversed(self.obj.__mro__):
+        for cls in reversed(self._mro):
             cls_annotations = doc_ast.walk_tree(cls).annotations.copy()
             dynamic_annotations = _safe_getattr(cls, "__annotations__", None)
             if isinstance(dynamic_annotations, dict):
@@ -622,10 +623,24 @@ class Class(Namespace[type]):
 
         return {k: v[1] for k, v in annotations.items()}
 
+    @cached_property
+    def _mro(self) -> tuple[type, ...]:
+        orig_bases = _safe_getattr(self.obj, "__orig_bases__", None)
+        if (
+            orig_bases
+            and _safe_getattr(orig_bases[-1], "__name__", None) == "TypedDict"
+        ):
+            # TypedDicts have a botched __mro__.
+            # However, if the subclasses also specify TypedDict as a base class, we can use __orig_bases__
+            # https://github.com/sphinx-doc/sphinx/pull/10806
+            return (self.obj, *orig_bases[:-1])
+        else:
+            return self.obj.__mro__
+
     @cached_property
     def _declarations(self) -> dict[str, tuple[str, str]]:
         decls: dict[str, tuple[str, str]] = {}
-        for cls in self.obj.__mro__:
+        for cls in self._mro:
             treeinfo = doc_ast.walk_tree(cls)
             for name in treeinfo.docstrings.keys() | treeinfo.annotations.keys():
                 decls.setdefault(name, (cls.__module__, f"{cls.__qualname__}.{name}"))
@@ -643,6 +658,7 @@ class Class(Namespace[type]):
             return self._declarations[member_name]
         except KeyError:  # pragma: no cover
             # TypedDict botches __mro__ and may need special casing here.
+            # One workaround is to also specify TypedDict as a base class, see pdoc.doc.Class._mro.
             warnings.warn(
                 f"Cannot determine where {self.fullname}.{member_name} is taken from, assuming current file."
             )
@@ -660,7 +676,7 @@ class Class(Namespace[type]):
     @cached_property
     def _member_objects(self) -> dict[str, Any]:
         unsorted: dict[str, Any] = {}
-        for cls in self.obj.__mro__:
+        for cls in self._mro:
             for name, obj in cls.__dict__.items():
                 unsorted.setdefault(name, obj)
         for name in self._var_docstrings:
@@ -683,7 +699,9 @@ class Class(Namespace[type]):
                 del unsorted["__init__"]
             elif issubclass(self.obj, dict):
                 # Special case: Do not show a constructor for dict subclasses.
-                del unsorted["__init__"]
+                unsorted.pop(
+                    "__init__", None
+                )  # TypedDict subclasses may not have __init__.
             else:
                 # Check if there's a helpful Metaclass.__call__ or Class.__new__. This dance is very similar to
                 # https://github.com/python/cpython/blob/9feae41c4f04ca27fd2c865807a5caeb50bf4fc4/Lib/inspect.py#L2359-L2376
@@ -707,7 +725,7 @@ class Class(Namespace[type]):
                         unsorted["__init__"] = new
 
         sorted: dict[str, Any] = {}
-        for cls in self.obj.__mro__:
+        for cls in self._mro:
             sorted, unsorted = doc_ast.sort_by_source(cls, sorted, unsorted)
         sorted.update(unsorted)
         return sorted
@@ -1020,7 +1038,11 @@ class Variable(Doc[None]):
     @cache
     @_include_fullname_in_traceback
     def __repr__(self):
-        return f'<var {self.qualname.rsplit(".")[-1]}{self.annotation_str}{self.default_value_str}{_docstr(self)}>'
+        if self.default_value_str:
+            default = f" = {self.default_value_str}"
+        else:
+            default = ""
+        return f'<var {self.qualname.rsplit(".")[-1]}{self.annotation_str}{default}{_docstr(self)}>'
 
     @cached_property
     def is_classvar(self) -> bool:
@@ -1043,15 +1065,15 @@ class Variable(Doc[None]):
         """The variable's default value as a pretty-printed str."""
         if self.default_value is empty:
             return ""
-        else:
-            try:
-                return re.sub(
-                    r" at 0x[0-9a-fA-F]+(?=>)",
-                    "",
-                    f" = {repr(self.default_value)}",
-                )
-            except Exception:
-                return " = <unable to get value representation>"
+
+        try:
+            pretty = repr(self.default_value)
+        except Exception as e:
+            warnings.warn(f"repr({self.fullname}) raised an exception ({e!r})")
+            return ""
+
+        pretty = re.sub(r" at 0x[0-9a-fA-F]+(?=>)", "", pretty)
+        return pretty
 
     @cached_property
     def annotation_str(self) -> str:
@@ -1176,6 +1198,7 @@ def _children(doc: Namespace) -> str:
         if not x.name.startswith("_") or x.name == "__init__"
     )
     if children:
+        children += "\n"
         children = f"\n{textwrap.indent(children, '    ')}"
     return children
 
